==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/AutoscaleNotificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.AutoscaleNotificationArgs.builder
import com.pulumi.azurenative.insights.kotlin.enums.OperationType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Autoscale notification.
 * @property email the email notification.
 * @property operation the operation associated with the notification and its value must be "scale"
 * @property webhooks the collection of webhook notifications.
 */
public data class AutoscaleNotificationArgs(
    public val email: Output<EmailNotificationArgs>? = null,
    public val operation: Output<OperationType>,
    public val webhooks: Output<List<WebhookNotificationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.AutoscaleNotificationArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.AutoscaleNotificationArgs =
        com.pulumi.azurenative.insights.inputs.AutoscaleNotificationArgs.builder()
            .email(email?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .operation(operation.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .webhooks(
                webhooks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AutoscaleNotificationArgs].
 */
@PulumiTagMarker
public class AutoscaleNotificationArgsBuilder internal constructor() {
    private var email: Output<EmailNotificationArgs>? = null

    private var operation: Output<OperationType>? = null

    private var webhooks: Output<List<WebhookNotificationArgs>>? = null

    /**
     * @param value the email notification.
     */
    @JvmName("rcgegdspkgekbhxf")
    public suspend fun email(`value`: Output<EmailNotificationArgs>) {
        this.email = value
    }

    /**
     * @param value the operation associated with the notification and its value must be "scale"
     */
    @JvmName("dpbtpeovwcuqcwsq")
    public suspend fun operation(`value`: Output<OperationType>) {
        this.operation = value
    }

    /**
     * @param value the collection of webhook notifications.
     */
    @JvmName("atqoawfxvcfhgucw")
    public suspend fun webhooks(`value`: Output<List<WebhookNotificationArgs>>) {
        this.webhooks = value
    }

    @JvmName("bbglhoxfodvpxfmc")
    public suspend fun webhooks(vararg values: Output<WebhookNotificationArgs>) {
        this.webhooks = Output.all(values.asList())
    }

    /**
     * @param values the collection of webhook notifications.
     */
    @JvmName("wojrvwrpihoxfirc")
    public suspend fun webhooks(values: List<Output<WebhookNotificationArgs>>) {
        this.webhooks = Output.all(values)
    }

    /**
     * @param value the email notification.
     */
    @JvmName("vgfepkjbdclduybk")
    public suspend fun email(`value`: EmailNotificationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.email = mapped
    }

    /**
     * @param argument the email notification.
     */
    @JvmName("wddqvxwlshbvhstv")
    public suspend fun email(argument: suspend EmailNotificationArgsBuilder.() -> Unit) {
        val toBeMapped = EmailNotificationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.email = mapped
    }

    /**
     * @param value the operation associated with the notification and its value must be "scale"
     */
    @JvmName("rxxbknaovcpqmhfg")
    public suspend fun operation(`value`: OperationType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    /**
     * @param value the collection of webhook notifications.
     */
    @JvmName("wvwoqmhwfbsxdkcp")
    public suspend fun webhooks(`value`: List<WebhookNotificationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.webhooks = mapped
    }

    /**
     * @param argument the collection of webhook notifications.
     */
    @JvmName("qgstbpkeumbwwdiv")
    public suspend fun webhooks(argument: List<suspend WebhookNotificationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WebhookNotificationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.webhooks = mapped
    }

    /**
     * @param argument the collection of webhook notifications.
     */
    @JvmName("xvbmgtdivuunlbdv")
    public suspend fun webhooks(vararg argument: suspend WebhookNotificationArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            WebhookNotificationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.webhooks = mapped
    }

    /**
     * @param argument the collection of webhook notifications.
     */
    @JvmName("defxgfmivjbwrmok")
    public suspend fun webhooks(argument: suspend WebhookNotificationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WebhookNotificationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.webhooks = mapped
    }

    /**
     * @param values the collection of webhook notifications.
     */
    @JvmName("vqucrcerlkyiobnj")
    public suspend fun webhooks(vararg values: WebhookNotificationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.webhooks = mapped
    }

    internal fun build(): AutoscaleNotificationArgs = AutoscaleNotificationArgs(
        email = email,
        operation = operation ?: throw PulumiNullFieldException("operation"),
        webhooks = webhooks,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/AutoscaleNotificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.AutoscaleNotificationArgs.builder
import com.pulumi.azurenative.insights.kotlin.enums.OperationType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Autoscale notification.
 * @property email the email notification.
 * @property operation the operation associated with the notification and its value must be "scale"
 * @property webhooks the collection of webhook notifications.
 */
public data class AutoscaleNotificationArgs(
    public val email: Output<EmailNotificationArgs>? = null,
    public val operation: Output<OperationType>,
    public val webhooks: Output<List<WebhookNotificationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.AutoscaleNotificationArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.AutoscaleNotificationArgs =
        com.pulumi.azurenative.insights.inputs.AutoscaleNotificationArgs.builder()
            .email(email?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .operation(operation.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .webhooks(
                webhooks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AutoscaleNotificationArgs].
 */
@PulumiTagMarker
public class AutoscaleNotificationArgsBuilder internal constructor() {
    private var email: Output<EmailNotificationArgs>? = null

    private var operation: Output<OperationType>? = null

    private var webhooks: Output<List<WebhookNotificationArgs>>? = null

    /**
     * @param value the email notification.
     */
    @JvmName("kgtdrrtpsnpurerq")
    public suspend fun email(`value`: Output<EmailNotificationArgs>) {
        this.email = value
    }

    /**
     * @param value the operation associated with the notification and its value must be "scale"
     */
    @JvmName("cxqeudnbpdiuucub")
    public suspend fun operation(`value`: Output<OperationType>) {
        this.operation = value
    }

    /**
     * @param value the collection of webhook notifications.
     */
    @JvmName("eeakndfnyliorojg")
    public suspend fun webhooks(`value`: Output<List<WebhookNotificationArgs>>) {
        this.webhooks = value
    }

    @JvmName("fwmxvkclebrjmdjc")
    public suspend fun webhooks(vararg values: Output<WebhookNotificationArgs>) {
        this.webhooks = Output.all(values.asList())
    }

    /**
     * @param values the collection of webhook notifications.
     */
    @JvmName("xbwmtbemmjersxvh")
    public suspend fun webhooks(values: List<Output<WebhookNotificationArgs>>) {
        this.webhooks = Output.all(values)
    }

    /**
     * @param value the email notification.
     */
    @JvmName("mhnokcwdcqmfdpcb")
    public suspend fun email(`value`: EmailNotificationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.email = mapped
    }

    /**
     * @param argument the email notification.
     */
    @JvmName("cwyewapvebnmxliq")
    public suspend fun email(argument: suspend EmailNotificationArgsBuilder.() -> Unit) {
        val toBeMapped = EmailNotificationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.email = mapped
    }

    /**
     * @param value the operation associated with the notification and its value must be "scale"
     */
    @JvmName("craprelshoyvafdu")
    public suspend fun operation(`value`: OperationType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    /**
     * @param value the collection of webhook notifications.
     */
    @JvmName("sykqtyekeehuauwe")
    public suspend fun webhooks(`value`: List<WebhookNotificationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.webhooks = mapped
    }

    /**
     * @param argument the collection of webhook notifications.
     */
    @JvmName("odffgbefdavwbxwt")
    public suspend fun webhooks(argument: List<suspend WebhookNotificationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WebhookNotificationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.webhooks = mapped
    }

    /**
     * @param argument the collection of webhook notifications.
     */
    @JvmName("roowtikjlwodkodf")
    public suspend fun webhooks(vararg argument: suspend WebhookNotificationArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            WebhookNotificationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.webhooks = mapped
    }

    /**
     * @param argument the collection of webhook notifications.
     */
    @JvmName("kkektpsijwlhujes")
    public suspend fun webhooks(argument: suspend WebhookNotificationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WebhookNotificationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.webhooks = mapped
    }

    /**
     * @param values the collection of webhook notifications.
     */
    @JvmName("yqkcgbhvmkhkwbyu")
    public suspend fun webhooks(vararg values: WebhookNotificationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.webhooks = mapped
    }

    internal fun build(): AutoscaleNotificationArgs = AutoscaleNotificationArgs(
        email = email,
        operation = operation ?: throw PulumiNullFieldException("operation"),
        webhooks = webhooks,
    )
}
